@@ -184,16 +184,28 @@ class Worker:
         workflow_uuid: str,
         meta: Dict[str, Any],
     ) -> None:
-        cur = self.conn.cursor()
-        cur.execute(
-            """
-            insert into paths (path_uuid, instance_uuid, workflow_uuid, meta)
-            values (%s, %s, %s, %s::jsonb);
-        """,
-            [path_uuid, instance_uuid, workflow_uuid, json.dumps(meta)],
-        )
-        self.conn.commit()
-        cur.close()
+        with self.conn.cursor() as cur:
+            cur.execute(
+                """
+                insert into paths (path_uuid, instance_uuid, workflow_uuid, meta)
+                values (%s, %s, %s, %s::jsonb);
+            """,
+                [path_uuid, instance_uuid, workflow_uuid, json.dumps(meta)],
+            )
+            self.conn.commit()
+
+    def close_path(
+        self,
+        path_uuid: str,
+        parent_id: Optional[int] = None,
+        workflow_uuid: Optional[str] = None,
+    ) -> None:
+        with self.conn.cursor() as cur:
+            cur.execute(
+                "select close_path(%s::uuid, %s::int, %s::uuid)",
+                [path_uuid, parent_id, workflow_uuid],
+            )
+            self.conn.commit()
 
     def path_uuid(self, task_id: str) -> str:
         with self.conn.cursor() as cur:
